==> pgsnapshot-0.1.1.tgz: pgsnapshot-0.1.1/src/pl/getRefreshMethod.pl <==
#--
#-- SUB: getRefreshMethod
#-- Returns the best refresh method supported by the SNAPSHOT refreshing process
#--
sub getRefreshMethod {
	#-- Function parameters
	my ($dbh, $snapshot, $masterschema, $mastername, $lastRefresh) = @_;

	#-- Local variables
	my $sql;
	my $sth;
	my $kind = $snapshot->{'kind'};
	my $row;

	if (($lastRefresh eq undef) || ($lastRefresh eq '1900-01-01 00:00:00')) { #-- It's the snapshot first refresh: always COMPLETE
		elog NOTICE, 'First Refresh detected.' if $main::DEBUG==1;
		$kind = 'C';
	} elsif (($kind eq 'R') or ($kind eq 'F')) { #-- The snapshot was created with REFRESH FORCE or REFRESH FAST
		#-- Test if LOG exists
		if (snapshotLogExists($dbh, $masterschema, $mastername)) {
			#-- count the rows at LOG
			my $logcount = countSnapshotLogModifiedRows($dbh, $masterschema, $mastername, $lastRefresh);
			#-- count the rows at MASTER
			$sql = <<SQL;
SELECT count(*) as total
FROM $masterschema.$mastername
SQL
			my ($mastercount) = sqlLookup($dbh, $sql, undef, 1);
			elog NOTICE, "Number of modified records: LOG=$logcount MASTER=$mastercount" if $main::DEBUG==1;
			#-- FAST only if count(LOG) le count(MASTER) / 4
			if (($kind eq 'F') || ($logcount le $mastercount)) {
				$kind = 'F';
			} else {
				elog NOTICE, "Huge number of modified records!" if $main::DEBUG==1;
				$kind = 'C';
			}
		} else {
			elog NOTICE, 'Snapshot Log does not exist.' if $main::DEBUG==1;
			$kind = 'C';
		}
		if (($snapshot->{'kind'} eq 'F') and ($kind ne 'F')) {
			#-- Can't do REFRESH FAST
			elog ERROR, 'Refresh FAST not supported. Did you set up a SNAPSHOT LOG correctly ?';
		}
	}
	return $kind;
}

==> pgsnapshot-0.2.0b.tgz: pgsnapshot-0.2.0b/src/pl/getRefreshMethod.pl <==
#--
#-- SUB: getRefreshMethod
#-- Returns the best refresh method supported by the SNAPSHOT refreshing process
#--
sub getRefreshMethod {
	#-- Function parameters
	my ($dbh, $snapshot, $masterschema, $mastername, $lastRefresh) = @_;

	#-- Local variables
	my $sql;
	my $sth;
	my $kind = $snapshot->{'kind'};
	my $row;

	if (($lastRefresh eq undef) || ($lastRefresh eq '1900-01-01 00:00:00')) { #-- It's the snapshot first refresh: always COMPLETE
		elog NOTICE, 'First Refresh detected.' if $main::DEBUG==1;
		$kind = 'C';
	} elsif (($kind eq 'R') or ($kind eq 'F')) { #-- The snapshot was created with REFRESH FORCE or REFRESH FAST
		#-- Test if LOG exists
		if (snapshotLogExists($dbh, $masterschema, $mastername)) {
			#-- count the rows at LOG
			my $logcount = countSnapshotLogModifiedRows($dbh, $masterschema, $mastername, $lastRefresh);
			#-- count the rows at MASTER
			if ("$snapshot->{'pbt_table'}" ne '') {
				$sql = <<SQL;
SELECT count(*) as total
FROM $masterschema.$snapshot->{'pbt_table'}
WHERE pbt\$ = $snapshot->{'snapid'}
SQL
			} else {
				$sql = <<SQL;
SELECT count(*) as total
FROM $masterschema.$mastername
SQL
			}
			my ($mastercount) = sqlLookup($dbh, $sql, ());
			elog NOTICE, "Number of modified records: LOG=$logcount MASTER=$mastercount" if $main::DEBUG==1;
			#-- FAST only if count(LOG) le count(MASTER) / 4
			if (($kind eq 'F') || ($logcount le $mastercount)) {
				$kind = 'F';
			} else {
				elog NOTICE, "Huge number of modified records!" if $main::DEBUG==1;
				$kind = 'C';
			}
		} else {
			elog NOTICE, 'Snapshot Log does not exist.' if $main::DEBUG==1;
			$kind = 'C';
		}
		if (($snapshot->{'kind'} eq 'F') and ($kind ne 'F')) {
			#-- Can't do REFRESH FAST
			elog ERROR, 'Refresh FAST not supported. Did you set up a SNAPSHOT LOG correctly ?';
		}
	}
	return $kind;
}
